==> risk-center-api-0.4.5-20180926.054523-29-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/DimensionAnalysisDto.java <==
package cn.com.duiba.tuia.risk.center.api.dto;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.util.Date;

@ApiModel
public class DimensionAnalysisDto implements Serializable {

    private static final long serialVersionUID = 7124943084398499183L;

    @ApiModelProperty("id")
    private Long id;

    @ApiModelProperty("日期")
    private Date curDate;

    @ApiModelProperty("维度，0-ip,1-device,2-ua")
    private Integer dimension;

    @ApiModelProperty("IP、device_id、UserAgent")
    private String metric;

    @ApiModelProperty("广告位访问UV")
    private Long sdkUv;

    @ApiModelProperty("活动参与UV")
    private Long participateUv;

    @ApiModelProperty("活动参与PV")
    private Long participatePv;

    @ApiModelProperty("发券量")
    private Long launchCount;

    @ApiModelProperty("券曝光量")
    private Long exposureCount;

    @ApiModelProperty("点击PV")
    private Long clickCount;

    @ApiModelProperty("落地页访问UV")
    private Long promoteVisitUv;

    @ApiModelProperty("落地页访问PV")
    private Long promoteVisitPv;

    @ApiModelProperty("落地页转化PV")
    private Long effectPv;

    @ApiModelProperty("ctr")
    private Double ctr;

    @ApiModelProperty("cvr")
    private Double cvr;

    @ApiModelProperty("创建时间")
    private Date gmtCreate;

    @ApiModelProperty("修改时间")
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Date getCurDate() {
        return curDate;
    }

    public void setCurDate(Date curDate) {
        this.curDate = curDate;
    }

    public Integer getDimension() {
        return dimension;
    }

    public void setDimension(Integer dimension) {
        this.dimension = dimension;
    }

    public String getMetric() {
        return metric;
    }

    public void setMetric(String metric) {
        this.metric = metric;
    }

    public Long getSdkUv() {
        return sdkUv;
    }

    public void setSdkUv(Long sdkUv) {
        this.sdkUv = sdkUv;
    }

    public Long getParticipateUv() {
        return participateUv;
    }

    public void setParticipateUv(Long participateUv) {
        this.participateUv = participateUv;
    }

    public Long getParticipatePv() {
        return participatePv;
    }

    public void setParticipatePv(Long participatePv) {
        this.participatePv = participatePv;
    }

    public Long getLaunchCount() {
        return launchCount;
    }

    public void setLaunchCount(Long launchCount) {
        this.launchCount = launchCount;
    }

    public Long getExposureCount() {
        return exposureCount;
    }

    public void setExposureCount(Long exposureCount) {
        this.exposureCount = exposureCount;
    }

    public Long getClickCount() {
        return clickCount;
    }

    public void setClickCount(Long clickCount) {
        this.clickCount = clickCount;
    }

    public Long getPromoteVisitUv() {
        return promoteVisitUv;
    }

    public void setPromoteVisitUv(Long promoteVisitUv) {
        this.promoteVisitUv = promoteVisitUv;
    }

    public Long getPromoteVisitPv() {
        return promoteVisitPv;
    }

    public void setPromoteVisitPv(Long promoteVisitPv) {
        this.promoteVisitPv = promoteVisitPv;
    }

    public Long getEffectPv() {
        return effectPv;
    }

    public void setEffectPv(Long effectPv) {
        this.effectPv = effectPv;
    }

    public Double getCtr() {
        return ctr;
    }

    public void setCtr(Double ctr) {
        this.ctr = ctr;
    }

    public Double getCvr() {
        return cvr;
    }

    public void setCvr(Double cvr) {
        this.cvr = cvr;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }


}

==> risk-center-api-0.4.9-20181031.053515-9-sources.jar: cn/com/duiba/tuia/risk/center/api/dto/DimensionAnalysisDto.java <==
package cn.com.duiba.tuia.risk.center.api.dto;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.util.Date;

@ApiModel
public class DimensionAnalysisDto implements Serializable {

    private static final long serialVersionUID = 7124943084398499183L;

    @ApiModelProperty("id")
    private Long id;

    @ApiModelProperty("日期")
    private Date curDate;

    @ApiModelProperty("维度，0-ip,1-device,2-ua")
    private Integer dimension;

    @ApiModelProperty("IP、device_id、UserAgent")
    private String metric;

    @ApiModelProperty("广告位访问UV")
    private Long sdkUv;

    @ApiModelProperty("活动参与UV")
    private Long participateUv;

    @ApiModelProperty("活动参与PV")
    private Long participatePv;

    @ApiModelProperty("发券量")
    private Long launchCount;

    @ApiModelProperty("券曝光量")
    private Long exposureCount;

    @ApiModelProperty("点击PV")
    private Long clickCount;

    @ApiModelProperty("落地页访问UV")
    private Long promoteVisitUv;

    @ApiModelProperty("落地页访问PV")
    private Long promoteVisitPv;

    @ApiModelProperty("落地页转化PV")
    private Long effectPv;

    @ApiModelProperty("ctr")
    private Double ctr;

    @ApiModelProperty("cvr")
    private Double cvr;

    @ApiModelProperty("创建时间")
    private Date gmtCreate;

    @ApiModelProperty("修改时间")
    private Date gmtModified;

    @ApiModelProperty("是否在黑名单中 0-否 1-是")
    private Integer belongBlacklist;

    public Integer getBelongBlacklist() {
        return belongBlacklist;
    }

    public void setBelongBlacklist(Integer belongBlacklist) {
        this.belongBlacklist = belongBlacklist;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Date getCurDate() {
        return curDate;
    }

    public void setCurDate(Date curDate) {
        this.curDate = curDate;
    }

    public Integer getDimension() {
        return dimension;
    }

    public void setDimension(Integer dimension) {
        this.dimension = dimension;
    }

    public String getMetric() {
        return metric;
    }

    public void setMetric(String metric) {
        this.metric = metric;
    }

    public Long getSdkUv() {
        return sdkUv;
    }

    public void setSdkUv(Long sdkUv) {
        this.sdkUv = sdkUv;
    }

    public Long getParticipateUv() {
        return participateUv;
    }

    public void setParticipateUv(Long participateUv) {
        this.participateUv = participateUv;
    }

    public Long getParticipatePv() {
        return participatePv;
    }

    public void setParticipatePv(Long participatePv) {
        this.participatePv = participatePv;
    }

    public Long getLaunchCount() {
        return launchCount;
    }

    public void setLaunchCount(Long launchCount) {
        this.launchCount = launchCount;
    }

    public Long getExposureCount() {
        return exposureCount;
    }

    public void setExposureCount(Long exposureCount) {
        this.exposureCount = exposureCount;
    }

    public Long getClickCount() {
        return clickCount;
    }

    public void setClickCount(Long clickCount) {
        this.clickCount = clickCount;
    }

    public Long getPromoteVisitUv() {
        return promoteVisitUv;
    }

    public void setPromoteVisitUv(Long promoteVisitUv) {
        this.promoteVisitUv = promoteVisitUv;
    }

    public Long getPromoteVisitPv() {
        return promoteVisitPv;
    }

    public void setPromoteVisitPv(Long promoteVisitPv) {
        this.promoteVisitPv = promoteVisitPv;
    }

    public Long getEffectPv() {
        return effectPv;
    }

    public void setEffectPv(Long effectPv) {
        this.effectPv = effectPv;
    }

    public Double getCtr() {
        return ctr;
    }

    public void setCtr(Double ctr) {
        this.ctr = ctr;
    }

    public Double getCvr() {
        return cvr;
    }

    public void setCvr(Double cvr) {
        this.cvr = cvr;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }


}
